Consumer

Enum Consumer 

pub enum Consumer {
    NotFound,
    Buried,
    NotIgnored,
    Beanstalk {
        error: BeanstalkError,
    },
    // some variants omitted
}
Errors which can occur when acting as a consumer/worker

Variants



NotFound

If the job does not exist or is not either reserved by the client



Buried

if the server ran out of memory trying to grow the priority queue data structure.



NotIgnored

If the client attempts to ignore the only tube in its watch list.



Beanstalk

Fields