pub enum Consumer {
NotFound,
Buried,
NotIgnored,
Beanstalk {
error: BeanstalkError,
},
// some variants omitted
}Expand description
Errors which can occur when acting as a consumer/worker
Variants
NotFound
If the job does not exist or is not either reserved by the client
Buried
if the server ran out of memory trying to grow the priority queue data structure.
NotIgnored
If the client attempts to ignore the only tube in its watch list.
Beanstalk
Fields

error: BeanstalkErrorTrait Implementations
Sourceimpl Fail for Consumer
impl Fail for Consumer
Sourcefn cause(&self) -> Option<&dyn Fail>
fn cause(&self) -> Option<&dyn Fail>
Returns a reference to the underlying cause of this failure, if it
is an error that wraps other errors. Read more
Sourcefn backtrace(&self) -> Option<&Backtrace>
fn backtrace(&self) -> Option<&Backtrace>
Returns a reference to the
Backtrace carried by this failure, if it
carries one. Read moreimpl Copy for Consumer
impl Eq for Consumer
impl StructuralPartialEq for Consumer