pub enum Put {
Buried,
ExpectedCRLF,
JobTooBig,
Draining,
Beanstalk {
error: BeanstalkError,
},
// some variants omitted
}Expand description
Errors which can be casued due to a PUT command
Variants
Buried
The server ran out of memory trying to grow the priority queue data structure. The client should try another server or disconnect and try again later.
ExpectedCRLF
The job body must be followed by a CR-LF pair, that is, “\r\n”. These two bytes are not counted in the job size given by the client in the put command line.
This should never happen, if it does please file an issue.
JobTooBig
The client has requested to put a job with a body larger than max-job-size bytes
Draining
This means that the server has been put into “drain mode” and is no longer accepting new jobs. The client should try another server or disconnect and try again later.
Beanstalk
Fields

error: BeanstalkErrorTrait Implementations
Sourceimpl Fail for Put
impl Fail for Put
Sourcefn cause(&self) -> Option<&dyn Fail>
fn cause(&self) -> Option<&dyn Fail>
Returns a reference to the underlying cause of this failure, if it
is an error that wraps other errors. Read more
Sourcefn backtrace(&self) -> Option<&Backtrace>
fn backtrace(&self) -> Option<&Backtrace>
Returns a reference to the
Backtrace carried by this failure, if it
carries one. Read moreimpl Copy for Put
impl Eq for Put
impl StructuralPartialEq for Put